@@ -3,7 +3,6 @@ use std::{
     collections::HashMap,
     ffi::c_void,
     rc::{Rc, Weak},
-    time::Duration,
 };
 
 use cocoa::{
@@ -11,7 +10,7 @@ use cocoa::{
         NSEvent, NSEventType, NSView, NSWindow, NSWindowCollectionBehavior, NSWindowStyleMask,
     },
     base::{id, nil, BOOL, NO, YES},
-    foundation::{NSArray, NSInteger, NSPoint, NSRect, NSSize, NSString, NSUInteger},
+    foundation::{NSArray, NSInteger, NSPoint, NSRect, NSSize, NSUInteger},
 };
 use cocoa::{
     appkit::{NSScreen, NSWindowTabbingMode},
@@ -134,6 +133,8 @@ impl PlatformWindow {
             let () =
                 msg_send![*self.platform_window, setContentViewController: *engine.view_controller];
 
+            let () = msg_send![*engine.view_controller, setMouseTrackingMode: 3]; // always track mouse
+
             // Temporarily set non empty window size so that flutter engine doesn't complain
             NSWindow::setContentSize_(*self.platform_window, Size::wh(1.0, 1.0).into());
         }
@@ -423,44 +424,49 @@ impl PlatformWindow {
     fn show_when_ready(weak_self: Weak<PlatformWindow>) {
         if let Some(s) = weak_self.upgrade() {
             autoreleasepool(|| unsafe {
-                let layer = NSWindow::contentView(*s.platform_window).layer();
-                let sublayers: id = msg_send![layer, sublayers];
-                let first = sublayers.objectAtIndex(0);
-                let contents: id = msg_send![first, contents];
-                if contents != nil {
-                    // This makes assumptions about FlutterView internals :-/
-                    let class: id = msg_send![contents, className];
-                    if !class.isEqualToString("IOSurface") {
-                        panic!("Expected IOSurface content");
-                    }
-                    let scale = NSWindow::backingScaleFactor(*s.platform_window);
-                    let content_size = NSView::frame(NSWindow::contentView(*s.platform_window));
+                // FIXME(knopp)
+                // This code used to check surface dimensions but it no longer
+                // adding metal compositing in engine broke it; The patch was reverted
+                // on the meanwhile though. Update this once the dust settles
 
-                    let expected_width = scale * content_size.size.width;
-                    let expected_height = scale * content_size.size.height;
-                    // IOSurface width/height
-                    let actual_width: NSInteger = msg_send![contents, width];
-                    let actual_height: NSInteger = msg_send![contents, height];
+                // let layer = NSWindow::contentView(*s.platform_window).layer();
+                // let sublayers: id = msg_send![layer, sublayers];
+                // let first = sublayers.objectAtIndex(0);
+                // let contents: id = msg_send![first, contents];
+                // if contents != nil {
+                //     // This makes assumptions about FlutterView internals :-/
+                //     let class: id = msg_send![contents, className];
+                //     if !class.isEqualToString("IOSurface") {
+                //         panic!("Expected IOSurface content");
+                //     }
+                //     let scale = NSWindow::backingScaleFactor(*s.platform_window);
+                //     let content_size = NSView::frame(NSWindow::contentView(*s.platform_window));
 
-                    // only show if size matches, otherwise we caught the view during resizing
-                    if actual_width == expected_width as NSInteger
-                        && actual_height == expected_height as NSInteger
-                    {
-                        s.actually_show();
-                        if let Some(delegate) = s.delegate.upgrade() {
-                            delegate.visibility_changed(true);
-                        };
-                        return;
-                    }
-                }
+                //     let expected_width = scale * content_size.size.width;
+                //     let expected_height = scale * content_size.size.height;
+                //     // IOSurface width/height
+                //     let actual_width: NSInteger = msg_send![contents, width];
+                //     let actual_height: NSInteger = msg_send![contents, height];
+
+                //     // only show if size matches, otherwise we caught the view during resizing
+                //     if actual_width == expected_width as NSInteger
+                //         && actual_height == expected_height as NSInteger
+                //     {
+                s.actually_show();
+                if let Some(delegate) = s.delegate.upgrade() {
+                    delegate.visibility_changed(true);
+                };
+                return;
+                // }
+                // }
                 // wait until we have content generated (with proper size)
-                s.context
-                    .run_loop
-                    .borrow()
-                    .schedule(Duration::from_secs_f64(1.0 / 60.0), move || {
-                        Self::show_when_ready(weak_self)
-                    })
-                    .detach();
+                // s.context
+                //     .run_loop
+                //     .borrow()
+                //     .schedule(Duration::from_secs_f64(1.0 / 60.0), move || {
+                //         Self::show_when_ready(weak_self)
+                //     })
+                //     .detach();
             })
         }
     }
